@@ -1199,6 +1199,16 @@ nickle_init (void)
 	  " Draw the 'id' subset of an RSVG object using the specified cairo context\n" },
 	{ 0 }
     };
+
+    Value nickle_version_value = lookupVar(0, "version");
+    char  *nickle_version = StrzPart(nickle_version_value, "invalid version");
+    if (strcmp(nickle_version, VERSION) != 0) {
+	RaiseStandardException(exception_open_error, 3,
+			       NewStrString("library built using nickle version " VERSION),
+			       NewInt(0), nickle_version_value);
+	RETURN(FalseVal);
+    }
+
     init_types ();
     
     BuiltinFuncs1 (&CairoNamespace, funcs_1);
